@@ -128,8 +128,7 @@ create_graph <- function(nodes_df = NULL,
   # Generate a random 8-character, alphanumeric
   # string to use as a graph ID
   graph_id <-
-    replicate(
-      8, sample(c(LETTERS, letters, 0:9), 1)) %>%
+    replicate(8, sample(c(LETTERS, letters, 0:9), 1)) %>%
     paste(collapse = "")
 
   # Create the `graph_info` data frame
@@ -141,7 +140,8 @@ create_graph <- function(nodes_df = NULL,
       graph_tz = graph_tz,
       write_backups = write_backups,
       display_msgs = display_msgs,
-      stringsAsFactors = FALSE)
+      stringsAsFactors = FALSE
+    )
 
   # Insert a user-defined `graph_name` if supplied
   if (!is.null(graph_name)) {
@@ -152,11 +152,12 @@ create_graph <- function(nodes_df = NULL,
 
   # Create an empty table for global graph attributes
   global_attrs <-
-    data.frame(
-      attr = as.character(NA),
-      value = as.character(NA),
-      attr_type = as.character(NA),
-      stringsAsFactors = FALSE)[-1, ]
+    dplyr::tibble(
+      attr = character(0),
+      value = character(0),
+      attr_type = character(0)
+    ) %>%
+    as.data.frame(stringsAsFactors = FALSE)
 
   # If `attr_theme` is `default` then populate the
   # `global_attrs` data frame with global graph attrs
@@ -174,46 +175,49 @@ create_graph <- function(nodes_df = NULL,
         kk = attr_theme_kk(),
         emit_error(
           fcn_name = fcn_name,
-          reasons = "The value for `attr_theme` doesn't refer to any available theme")
+          reasons = "The value for `attr_theme` doesn't refer to any available theme"
+        )
       )
 
   } else if (is.null(attr_theme)) {
 
     global_attrs <-
-      data.frame(
-        attr = as.character(NA),
-        value = as.character(NA),
-        attr_type = as.character(NA),
-        stringsAsFactors = FALSE)[-1, ]
+      dplyr::tibble(
+        attr = character(0),
+        value = character(0),
+        attr_type = character(0)
+      ) %>%
+      as.data.frame(stringsAsFactors = FALSE)
   }
 
   ## DF: `nodes_df`
 
   # Create an empty node data frame (`ndf`)
   ndf <-
-    data.frame(
-      id = as.integer(NA),
-      type = as.character(NA),
-      label = as.character(NA),
-      stringsAsFactors = FALSE)[-1, ]
+    dplyr::tibble(
+      id = integer(0),
+      type = character(0),
+      label = character(0)
+    ) %>%
+    as.data.frame(stringsAsFactors = FALSE)
 
   ## DF: `edges_df`
 
   # Create an empty edge data frame (`edf`)
   edf <-
-    data.frame(
-      id = as.integer(NA),
-      from = as.integer(NA),
-      to = as.integer(NA),
-      rel = as.character(NA),
-      stringsAsFactors = FALSE)[-1, ]
+    dplyr::tibble(
+      id = integer(0),
+      from = integer(0),
+      to = integer(0),
+      rel = character(0)
+    ) %>%
+    as.data.frame(stringsAsFactors = FALSE)
 
   ## DF: `node_selection`
 
   # Create an empty node selection data frame (`nsdf`)
   nsdf <-
-    dplyr::tibble(
-      node = as.integer(NA))[-1, ] %>%
+    dplyr::tibble(node = integer(0)) %>%
     as.data.frame(stringsAsFactors = FALSE)
 
   ## DF: `edge_selection`
@@ -221,35 +225,38 @@ create_graph <- function(nodes_df = NULL,
   # Create an empty edge selection data frame (`esdf`)
   esdf <-
     dplyr::tibble(
-      edge = as.integer(NA),
-      from = as.integer(NA),
-      to = as.integer(NA))[-1, ] %>%
+      edge = integer(0),
+      from = integer(0),
+      to = integer(0)
+    ) %>%
     as.data.frame(stringsAsFactors = FALSE)
 
   ## DF: `graph_actions`
 
   # Create an empty `graph_actions` data frame
   graph_actions <-
-    data.frame(
-      action_index = as.integer(NA),
-      action_name = as.character(NA),
-      expression = as.character(NA),
-      stringsAsFactors = FALSE)[-1, ]
+    dplyr::tibble(
+      action_index = integer(0),
+      action_name = character(0),
+      expression = character(0)
+    ) %>%
+    as.data.frame(stringsAsFactors = FALSE)
 
   ## DF: `graph_log`
 
   # Create an empty `graph_log` data frame
   graph_log <-
-    data.frame(
-      version_id = as.integer(NA),
-      function_used = as.character(NA),
+    dplyr::tibble(
+      version_id = integer(0),
+      function_used = character(0),
       time_modified = graph_time,
-      duration = as.numeric(NA),
-      nodes = as.integer(NA),
-      edges = as.integer(NA),
-      d_n = as.integer(NA),
-      d_e = as.integer(NA),
-      stringsAsFactors = FALSE)[-1, ]
+      duration = numeric(0),
+      nodes = integer(0),
+      edges = integer(0),
+      d_n = integer(0),
+      d_e = integer(0)
+    ) %>%
+    as.data.frame(stringsAsFactors = FALSE)
 
   ## list: `cache`
 
@@ -272,7 +279,8 @@ create_graph <- function(nodes_df = NULL,
       edge_selection = esdf,
       cache = cache,
       graph_actions = graph_actions,
-      graph_log = graph_log)
+      graph_log = graph_log
+    )
 
   attr(graph, "class") <- "dgr_graph"
 
@@ -291,7 +299,8 @@ create_graph <- function(nodes_df = NULL,
         nodes = nrow(graph$nodes_df),
         edges = nrow(graph$edges_df),
         d_n = nrow(graph$nodes_df),
-        d_e = nrow(graph$edges_df))
+        d_e = nrow(graph$edges_df)
+      )
 
   } else if (!is.null(nodes_df) & is.null(edges_df)) {
 
@@ -310,8 +319,7 @@ create_graph <- function(nodes_df = NULL,
     }
 
     # Bind the nodes to the `nodes_df` df in the graph
-    graph$nodes_df <-
-      dplyr::bind_rows(graph$nodes_df, nodes_df)
+    graph$nodes_df <- dplyr::bind_rows(graph$nodes_df, nodes_df)
 
     # Modify the `last_node` vector
     graph$last_node <- nrow(nodes_df)
@@ -327,7 +335,8 @@ create_graph <- function(nodes_df = NULL,
         nodes = nrow(graph$nodes_df),
         edges = nrow(graph$edges_df),
         d_n = nrow(graph$nodes_df),
-        d_e = nrow(graph$edges_df))
+        d_e = nrow(graph$edges_df)
+      )
 
   } else if (!is.null(nodes_df) & !is.null(edges_df)) {
 
