@@ -318,7 +318,7 @@ trav_out_node <- function(graph,
       starting_edges %>%
       dplyr::semi_join(valid_nodes, by = "from") %>%
       dplyr::left_join(edf, by = c("edge" = "id")) %>%
-      dplyr::select_("from.y", copy_attrs_from)
+      dplyr::select("from.y",!! enquo(copy_attrs_from))
 
     if (!is.null(copy_attrs_as)) {
 
@@ -336,10 +336,9 @@ trav_out_node <- function(graph,
       nodes %>%
       dplyr::rename(id = from.y) %>%
       dplyr::group_by(id) %>%
-      dplyr::summarize_(.dots = stats::setNames(
-        list(stats::as.formula(
-          paste0("~", agg, "(", copy_attrs_from, ", na.rm = TRUE)"))),
-        copy_attrs_from)) %>%
+      dplyr::summarize(!! copy_attrs_from :=
+                         match.fun(!! agg)(!! as.name(copy_attrs_from),
+                                           na.rm = TRUE)) %>%
       dplyr::right_join(ndf, by = "id") %>%
       dplyr::select(id, type, label, dplyr::everything()) %>%
       as.data.frame(stringsAsFactors = FALSE)
