@@ -8,37 +8,53 @@ test_that("an empty graph object can be created and such an object is correct",
   # Expect that names in graph object match a
   # prescribed set of names
   expect_true(
-    all(names(graph) ==
-          c("graph_info", "nodes_df", "edges_df",
-            "global_attrs", "directed",
-            "last_node", "last_edge",
-            "node_selection", "edge_selection",
-            "graph_log")))
+    all(
+      names(graph) ==
+        c(
+          "graph_info",
+          "nodes_df",
+          "edges_df",
+          "global_attrs",
+          "directed",
+          "last_node",
+          "last_edge",
+          "node_selection",
+          "edge_selection",
+          "cache",
+          "graph_actions",
+          "graph_log")))
 
   # Expect a graph object of class `dgr_graph`
-  expect_is(graph, "dgr_graph")
+  expect_is(
+    graph, "dgr_graph")
 
   # Expect that the `nodes_df` component is
   # a data frame
-  expect_is(graph$nodes_df, "data.frame")
+  expect_is(
+    graph$nodes_df, "data.frame")
 
   # Expect that the `edges_df` component is
   # a data frame
-  expect_is(graph$edges_df ,"data.frame")
+  expect_is(
+    graph$edges_df , "data.frame")
 
   # Expect that the use of `is_graph_empty()` function
   # will result in TRUE
-  expect_true(is_graph_empty(graph))
+  expect_true(
+    is_graph_empty(graph))
 
   # Expect that the `global_attrs` component is not NULL
-  expect_true(!is.null(graph$global_attrs))
+  expect_true(
+    !is.null(graph$global_attrs))
 
   # Expect that the empty graph is directed by default
-  expect_true(graph$directed)
+  expect_true(
+    graph$directed)
 
   # Expect that the `is_graph_directed()` function
   # will return TRUE
-  expect_true(is_graph_directed(graph))
+  expect_true(
+    is_graph_directed(graph))
 })
 
 test_that("a graph object with nodes can be created correctly", {
@@ -60,37 +76,55 @@ test_that("a graph object with nodes can be created correctly", {
   # Expect that names in this graph object match a
   # prescribed set of names
   expect_true(
-    all(names(graph) ==
-          c("graph_info", "nodes_df", "edges_df",
-            "global_attrs", "directed",
-            "last_node", "last_edge",
-            "node_selection", "edge_selection",
-            "graph_log")))
+    all(
+      names(graph) ==
+        c(
+          "graph_info",
+          "nodes_df",
+          "edges_df",
+          "global_attrs",
+          "directed",
+          "last_node",
+          "last_edge",
+          "node_selection",
+          "edge_selection",
+          "cache",
+          "graph_actions",
+          "graph_log")))
 
   # Expect a graph object of class `dgr_graph`
-  expect_is(graph, "dgr_graph")
+  expect_is(
+    graph, "dgr_graph")
 
   # Expect that several of the graph components
   # are not NULL
-  expect_true(!is.null(graph$nodes_df))
-  expect_true(!is.null(graph$global_attrs))
+  expect_true(
+    !is.null(graph$nodes_df))
+
+  expect_true(
+    !is.null(graph$global_attrs))
 
   # Expect that the `nodes_df` component is
   # a data frame
-  expect_is(graph$nodes_df, "data.frame")
+  expect_is(
+    graph$nodes_df, "data.frame")
 
   # Expect that the `edges_df` component is
   # a data frame
-  expect_is(graph$edges_df ,"data.frame")
+  expect_is(
+    graph$edges_df , "data.frame")
 
   # Expect that the graph is a directed graph
-  expect_true(graph$directed == TRUE)
+  expect_true(
+    graph$directed == TRUE)
 
   # Expect that the `nodes_df` df has 7 columns
-  expect_true(ncol(graph$nodes_df) == 7)
+  expect_true(
+    ncol(graph$nodes_df) == 7)
 
   # Expect that the `nodes_df` df has 4 rows
-  expect_true(nrow(graph$nodes_df) == 4)
+  expect_true(
+    nrow(graph$nodes_df) == 4)
 })
 
 test_that("a graph object with nodes and edges can be created correctly", {
@@ -123,39 +157,57 @@ test_that("a graph object with nodes and edges can be created correctly", {
   # Expect that names in this graph object match a
   # prescribed set of names
   expect_true(
-    all(names(graph) ==
-          c("graph_info", "nodes_df", "edges_df",
-            "global_attrs", "directed",
-            "last_node", "last_edge",
-            "node_selection", "edge_selection",
-            "graph_log")))
+    all(
+      names(graph) ==
+        c(
+          "graph_info",
+          "nodes_df",
+          "edges_df",
+          "global_attrs",
+          "directed",
+          "last_node",
+          "last_edge",
+          "node_selection",
+          "edge_selection",
+          "cache",
+          "graph_actions",
+          "graph_log")))
 
   # Expect a graph object of class `dgr_graph`
-  expect_is(graph, "dgr_graph")
+  expect_is(
+    graph, "dgr_graph")
 
   # Expect that the `global_attrs` component is not NULL
-  expect_true(!is.null(graph$global_attrs))
+  expect_true(
+    !is.null(graph$global_attrs))
 
   # Expect that the `nodes_df` component is
   # a data frame
-  expect_is(graph$nodes_df, "data.frame")
+  expect_is(
+    graph$nodes_df, "data.frame")
 
   # Expect that the `edges_df` component is
   # a data frame
-  expect_is(graph$edges_df ,"data.frame")
+  expect_is(
+    graph$edges_df , "data.frame")
 
   # Expect that the graph is a directed graph
-  expect_true(graph$directed == TRUE)
+  expect_true(
+    graph$directed == TRUE)
 
   # Expect that the `nodes_df` df has 7 columns
-  expect_true(ncol(graph$nodes_df) == 7)
+  expect_true(
+    ncol(graph$nodes_df) == 7)
 
   # Expect that the `nodes_df` df has 4 rows
-  expect_true(nrow(graph$nodes_df) == 4)
+  expect_true(
+    nrow(graph$nodes_df) == 4)
 
   # Expect that the `edges_df` df has 4 columns
-  expect_true(ncol(graph$edges_df) == 4)
+  expect_true(
+    ncol(graph$edges_df) == 4)
 
   # Expect that the `edges_df` df has 3 rows
-  expect_true(nrow(graph$edges_df) == 3)
+  expect_true(
+    nrow(graph$edges_df) == 3)
 })
