@@ -7,10 +7,9 @@ test_that("copying values with `trav_out_edge()` works", {
     create_graph() %>%
     add_path(
       n = 3,
-      node_data = node_data(
-        data = c(1.0, 2.0, 3.0)),
-      edge_data = edge_data(
-        data = c(1.5, 2.5)))
+      node_data = node_data(data = c(1.0, 2.0, 3.0)),
+      edge_data = edge_data(data = c(1.5, 2.5))
+    )
 
   # Select node ID `1`, traverse to
   # outward edges and copy the `data`
@@ -21,20 +20,15 @@ test_that("copying values with `trav_out_edge()` works", {
     trav_out_edge(copy_attrs_from = data)
 
   # Expect that there are 5 columns in the edf
-  expect_equal(
-    ncol(graph$edges_df), 5)
+  expect_equal(ncol(graph$edges_df), 5)
 
   # Expect that the `data` column is
   # the last column in edf
-  expect_equal(
-    colnames(graph$edges_df)[length(colnames(graph$edges_df))],
-    "data")
+  expect_equal(colnames(graph$edges_df)[length(colnames(graph$edges_df))], "data")
 
   # Expect certain values in the
   # `value` column of the edf
-  expect_equal(
-    graph$edges_df$data,
-    c(1.0, 2.5))
+  expect_equal(graph$edges_df$data, c(1.0, 2.5))
 
   #
   # Test where there are no common column names
@@ -45,10 +39,9 @@ test_that("copying values with `trav_out_edge()` works", {
     create_graph() %>%
     add_path(
       n = 3,
-      node_data = node_data(
-        node_value = c(1.0, 2.0, 3.0)),
-      edge_data = edge_data(
-        edge_value = c(1.5, 2.5)))
+      node_data = node_data(node_value = c(1.0, 2.0, 3.0)),
+      edge_data = edge_data(edge_value = c(1.5, 2.5))
+    )
 
   # Select node ID `1`, traverse to
   # outward edges, copy value from
@@ -59,24 +52,18 @@ test_that("copying values with `trav_out_edge()` works", {
     trav_out_edge(copy_attrs_from = node_value)
 
   # Expect that there are 6 columns in the edf
-  expect_equal(
-    ncol(graph$edges_df), 6)
+  expect_equal(ncol(graph$edges_df), 6)
 
   # Expect that the `edge_value`
   # column in the last column in
   # the edge data frame
-  expect_equal(
-    colnames(graph$edges_df)[length(colnames(graph$edges_df))],
-    "edge_value")
+  expect_equal(colnames(graph$edges_df)[length(colnames(graph$edges_df))], "edge_value")
 
   # Expect certain values in the `node_value` column of the
   # edge data frame
-  expect_equal(
-    graph$edges_df$node_value,
-    c(1, NA))
+  expect_equal(graph$edges_df$node_value, c(1, NA))
 })
 
-
 test_that("copying values with `trav_in_edge()` works", {
 
   # Create a graph with a path
@@ -84,10 +71,11 @@ test_that("copying values with `trav_in_edge()` works", {
     create_graph() %>%
     add_path(
       n = 3,
-      node_data = node_data(
-        data = c(1.0, 2.0, 3.0)),
-      edge_data = edge_data(
-        data = c(1.5, 2.5)))
+      node_data = node_data(data = c(15, 20, 30)),
+      edge_data = edge_data(data = c(1.5, 2.5))
+    ) %>%
+    set_node_attr_to_display(attr = "data") %>%
+    set_edge_attr_to_display(attr = "data")
 
   # Select node ID `3`, traverse to
   # inward edges and copy the `data`
@@ -97,21 +85,16 @@ test_that("copying values with `trav_in_edge()` works", {
     select_nodes_by_id(nodes = 3) %>%
     trav_in_edge(copy_attrs_from = data)
 
-  # Expect that there are 5 columns in the edf
-  expect_equal(
-    ncol(graph$edges_df), 5)
+  # Expect that there are 6 columns in the edf
+  expect_equal(ncol(graph$edges_df), 6)
 
   # Expect that the `data` column is
   # the last column in edf
-  expect_equal(
-    colnames(graph$edges_df)[length(colnames(graph$edges_df))],
-    "data")
+  expect_equal(colnames(graph$edges_df)[length(colnames(graph$edges_df))], "data")
 
   # Expect certain values in the
   # `value` column of the edf
-  expect_equal(
-    graph$edges_df$data,
-    c(1.5, 3.0))
+  expect_equal(graph$edges_df$data, c(1.5, 30))
 
   #
   # Test where there are no common column names
@@ -122,10 +105,11 @@ test_that("copying values with `trav_in_edge()` works", {
     create_graph() %>%
     add_path(
       n = 3,
-      node_data = node_data(
-        node_value = c(1.0, 2.0, 3.0)),
-      edge_data = edge_data(
-        edge_value = c(1.5, 2.5)))
+      node_data = node_data(node_value = c(15, 20, 30)),
+      edge_data = edge_data(edge_value = c(1.5, 2.5))
+    ) %>%
+    set_node_attr_to_display(attr = "node_value") %>%
+    set_edge_attr_to_display(attr = "edge_value")
 
   # Select node ID `3`, traverse to
   # outward edges, copy value from
@@ -135,25 +119,19 @@ test_that("copying values with `trav_in_edge()` works", {
     select_nodes_by_id(nodes = 3) %>%
     trav_in_edge(copy_attrs_from = node_value)
 
-  # Expect that there are 6 columns in the edf
-  expect_equal(
-    ncol(graph$edges_df), 6)
+  # Expect that there are 7 columns in the edf
+  expect_equal(ncol(graph$edges_df), 7)
 
   # Expect that the `edge_value`
   # column in the last column in
   # the edge data frame
-  expect_equal(
-    colnames(graph$edges_df)[length(colnames(graph$edges_df))],
-    "edge_value")
+  expect_equal(colnames(graph$edges_df)[length(colnames(graph$edges_df))], "edge_value")
 
   # Expect certain values in the `node_value` column of the
   # edge data frame
-  expect_equal(
-    graph$edges_df$node_value,
-    c(NA, 3))
+  expect_equal(graph$edges_df$node_value, c(NA, 30))
 })
 
-
 test_that("copying values with `trav_both_edge()` works", {
 
   # Create a graph with a path
@@ -161,10 +139,9 @@ test_that("copying values with `trav_both_edge()` works", {
     create_graph() %>%
     add_path(
       n = 3,
-      node_data = node_data(
-        data = c(1.0, 2.0, 3.0)),
-      edge_data = edge_data(
-        data = c(1.5, 2.5)))
+      node_data = node_data(data = c(1.0, 2.0, 3.0)),
+      edge_data = edge_data(data = c(1.5, 2.5))
+    )
 
   # Select node ID `2`, traverse to
   # inward/outward edges and copy the `data`
@@ -175,20 +152,15 @@ test_that("copying values with `trav_both_edge()` works", {
     trav_both_edge(copy_attrs_from = data)
 
   # Expect that there are 5 columns in the edf
-  expect_equal(
-    ncol(graph$edges_df), 5)
+  expect_equal(ncol(graph$edges_df), 5)
 
   # Expect that the `data` column is
   # the last column in edf
-  expect_equal(
-    colnames(graph$edges_df)[length(colnames(graph$edges_df))],
-    "data")
+  expect_equal(colnames(graph$edges_df)[length(colnames(graph$edges_df))], "data")
 
   # Expect certain values in the
   # `value` column of the edf
-  expect_equal(
-    graph$edges_df$data,
-    c(3.5, 4.5))
+  expect_equal(graph$edges_df$data, c(3.5, 4.5))
 
   #
   # Test where there are no common column names
@@ -199,10 +171,9 @@ test_that("copying values with `trav_both_edge()` works", {
     create_graph() %>%
     add_path(
       n = 3,
-      node_data = node_data(
-        node_value = c(1.0, 2.0, 3.0)),
-      edge_data = edge_data(
-        edge_value = c(1.5, 2.5)))
+      node_data = node_data(node_value = c(1.0, 2.0, 3.0)),
+      edge_data = edge_data(edge_value = c(1.5, 2.5))
+    )
 
   # Select node ID `2`, traverse to
   # inward/outward edges, copy value from
@@ -213,24 +184,18 @@ test_that("copying values with `trav_both_edge()` works", {
     trav_both_edge(copy_attrs_from = node_value)
 
   # Expect that there are 6 columns in the edf
-  expect_equal(
-    ncol(graph$edges_df), 6)
+  expect_equal(ncol(graph$edges_df), 6)
 
   # Expect that the `edge_value`
   # column in the last column in
   # the edge data frame
-  expect_equal(
-    colnames(graph$edges_df)[length(colnames(graph$edges_df))],
-    "edge_value")
+  expect_equal(colnames(graph$edges_df)[length(colnames(graph$edges_df))], "edge_value")
 
   # Expect certain values in the `node_value` column of the
   # edge data frame
-  expect_equal(
-    graph$edges_df$node_value,
-    c(2, 2))
+  expect_equal(graph$edges_df$node_value, c(2, 2))
 })
 
-
 test_that("copying values with `trav_both()` works", {
 
   # Create a graph with a path
@@ -238,10 +203,9 @@ test_that("copying values with `trav_both()` works", {
     create_graph() %>%
     add_path(
       n = 3,
-      node_data = node_data(
-        data = c(1.0, 2.0, 3.0)),
-      edge_data = edge_data(
-        data = c(1.5, 2.5)))
+      node_data = node_data(data = c(1.0, 2.0, 3.0)),
+      edge_data = edge_data(data = c(1.5, 2.5))
+    )
 
   # Select node ID `2`, traverse to
   # inward/outward nodes and copy the `data`
@@ -253,9 +217,7 @@ test_that("copying values with `trav_both()` works", {
 
   # Expect certain values in the `node_value` column of the
   # edge data frame
-  expect_equal(
-    graph$nodes_df$data,
-    c(2, 2, 2))
+  expect_equal(graph$nodes_df$data, c(2, 2, 2))
 })
 
 test_that("copying values with `trav_in()` works", {
@@ -265,10 +227,9 @@ test_that("copying values with `trav_in()` works", {
     create_graph() %>%
     add_path(
       n = 3,
-      node_data = node_data(
-        data = c(1.0, 2.0, 3.0)),
-      edge_data = edge_data(
-        data = c(1.5, 2.5)))
+      node_data = node_data(data = c(1.0, 2.0, 3.0)),
+      edge_data = edge_data(data = c(1.5, 2.5))
+    )
 
   # Select node ID `3`, traverse to
   # inward/outward edges and copy the `data`
@@ -279,20 +240,15 @@ test_that("copying values with `trav_in()` works", {
     trav_in(copy_attrs_from = data)
 
   # Expect that there are 4 columns in the edf
-  expect_equal(
-    ncol(graph$nodes_df), 4)
+  expect_equal(ncol(graph$nodes_df), 4)
 
   # Expect that the `data` column is
   # the last column in ndf
-  expect_equal(
-    colnames(graph$nodes_df)[length(colnames(graph$nodes_df))],
-    "data")
+  expect_equal(colnames(graph$nodes_df)[length(colnames(graph$nodes_df))], "data")
 
   # Expect certain values in the
   # `value` column of the edf
-  expect_equal(
-    graph$nodes_df$data,
-    c(1, 3, 3))
+  expect_equal(graph$nodes_df$data, c(1, 3, 3))
 })
 
 test_that("copying values with `trav_out()` works", {
@@ -302,10 +258,9 @@ test_that("copying values with `trav_out()` works", {
     create_graph() %>%
     add_path(
       n = 3,
-      node_data = node_data(
-        data = c(1.0, 2.0, 3.0)),
-      edge_data = edge_data(
-        data = c(1.5, 2.5)))
+      node_data = node_data(data = c(1.0, 2.0, 3.0)),
+      edge_data = edge_data(data = c(1.5, 2.5))
+    )
 
   # Select node ID `1`, traverse to
   # outward nodes and copy the `data`
@@ -316,23 +271,17 @@ test_that("copying values with `trav_out()` works", {
     trav_out(copy_attrs_from = data)
 
   # Expect that there are 4 columns in the ndf
-  expect_equal(
-    ncol(graph$nodes_df), 4)
+  expect_equal(ncol(graph$nodes_df), 4)
 
   # Expect that the `data` column is
   # the last column in ndf
-  expect_equal(
-    colnames(graph$nodes_df)[length(colnames(graph$nodes_df))],
-    "data")
+  expect_equal(colnames(graph$nodes_df)[length(colnames(graph$nodes_df))], "data")
 
   # Expect certain values in the
   # `value` column of the edf
-  expect_equal(
-    graph$nodes_df$data,
-    c(1, 1, 3))
+  expect_equal(graph$nodes_df$data, c(1, 1, 3))
 })
 
-
 test_that("copying values with `trav_out_node()` works", {
 
   # Create a graph
@@ -340,24 +289,16 @@ test_that("copying values with `trav_out_node()` works", {
     create_graph() %>%
     add_node() %>%
     select_nodes() %>%
-    add_n_nodes_ws(
-      n = 2,
-      direction = "from") %>%
+    add_n_nodes_ws(n = 2, direction = "from") %>%
     clear_selection() %>%
     select_nodes_by_id(nodes = 2) %>%
-    set_node_attrs_ws(
-      node_attr = value,
-      value = 8) %>%
+    set_node_attrs_ws(node_attr = value, value = 8) %>%
     clear_selection() %>%
     select_edges_by_edge_id(edges = 1) %>%
-    set_edge_attrs_ws(
-      edge_attr = value,
-      value = 5) %>%
+    set_edge_attrs_ws(edge_attr = value, value = 5) %>%
     clear_selection() %>%
     select_edges_by_edge_id(edges = 2) %>%
-    set_edge_attrs_ws(
-      edge_attr = value,
-      value = 5) %>%
+    set_edge_attrs_ws(edge_attr = value, value = 5) %>%
     clear_selection() %>%
     select_edges()
 
@@ -365,12 +306,11 @@ test_that("copying values with `trav_out_node()` works", {
   # from selected nodes and passed to adjacent nodes
   expect_equal(
     graph %>%
-      trav_out_node(
-        copy_attrs_from = value,
-        agg = "sum") %>%
+      trav_out_node(copy_attrs_from = value, agg = "sum") %>%
       get_node_attrs(node_attr = value) %>%
       as.numeric(),
-    c(10, 8, NA))
+    c(10, 8, NA)
+  )
 })
 
 test_that("copying values with `trav_in_node()` works", {
@@ -380,24 +320,16 @@ test_that("copying values with `trav_in_node()` works", {
     create_graph() %>%
     add_node() %>%
     select_nodes() %>%
-    add_n_nodes_ws(
-      n = 2,
-      direction = "to") %>%
+    add_n_nodes_ws(n = 2, direction = "to") %>%
     clear_selection() %>%
     select_nodes_by_id(nodes = 2) %>%
-    set_node_attrs_ws(
-      node_attr = value,
-      value = 8) %>%
+    set_node_attrs_ws(node_attr = value, value = 8) %>%
     clear_selection() %>%
     select_edges_by_edge_id(edges = 1) %>%
-    set_edge_attrs_ws(
-      edge_attr = value,
-      value = 5) %>%
+    set_edge_attrs_ws(edge_attr = value, value = 5) %>%
     clear_selection() %>%
     select_edges_by_edge_id(edges = 2) %>%
-    set_edge_attrs_ws(
-      edge_attr = value,
-      value = 5) %>%
+    set_edge_attrs_ws(edge_attr = value, value = 5) %>%
     clear_selection() %>%
     select_edges()
 
@@ -405,10 +337,9 @@ test_that("copying values with `trav_in_node()` works", {
   # from selected nodes and passed to adjacent nodes
   expect_equal(
     graph %>%
-      trav_in_node(
-        copy_attrs_from = value,
-        agg = "sum") %>%
+      trav_in_node(copy_attrs_from = value, agg = "sum") %>%
       get_node_attrs(node_attr = value) %>%
       as.numeric(),
-    c(10, 8, NA))
+    c(10, 8, NA)
+  )
 })
